<?php
/**
 * The main template for implementing Theme/Customzer Options
 *
 * @package Catch Themes
 * @subpackage Clean Journal Pro
 * @since Clean Journal 1.0
 */

if ( ! defined( 'CLEAN_JOURNAL_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


/**
 * Implements journal theme options into Theme Customizer.
 *
 * @param $wp_customize Theme Customizer object
 * @return void
 *
 * @since Clean Journal 1.0
 */
function clean_journal_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport			= 'postMessage';

	/**
	  * Set priority of blogname (Site Title) to 1.
	  *  Strangly, if more than two options is added, Site title is moved below Tagline. This rectifies this issue.
	  */
	$wp_customize->get_control( 'blogname' )->priority			= 1;

	$wp_customize->get_setting( 'blogdescription' )->transport	= 'postMessage';

	$options  = clean_journal_get_theme_options();

	$defaults = clean_journal_get_default_theme_options();

	//Custom Controls
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-custom-controls.php';

	//@remove Remove this block when WordPress 4.8 is released
	if ( ! function_exists( 'has_custom_logo' ) ) {
		// Custom Logo (added to Site Title and Tagline section in Theme Customizer)
		$wp_customize->add_setting( 'clean_journal_theme_options[logo]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['logo'],
			'sanitize_callback'	=> 'clean_journal_sanitize_image'
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo', array(
			'label'		=> __( 'Logo', 'clean-journal-pro' ),
			'priority'	=> 100,
			'section'   => 'title_tagline',
	        'settings'  => 'clean_journal_theme_options[logo]',
	    ) ) );

	    $wp_customize->add_setting( 'clean_journal_theme_options[logo_disable]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['logo_disable'],
			'sanitize_callback' => 'clean_journal_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'clean_journal_theme_options[logo_disable]', array(
			'label'    => __( 'Check to disable logo', 'clean-journal-pro' ),
			'priority' => 101,
			'section'  => 'title_tagline',
			'settings' => 'clean_journal_theme_options[logo_disable]',
			'type'     => 'checkbox',
		) );

		$wp_customize->add_setting( 'clean_journal_theme_options[logo_alt_text]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['logo_alt_text'],
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'clean_journal_logo_alt_text', array(
			'label'    	=> __( 'Logo Alt Text', 'clean-journal-pro' ),
			'priority'	=> 102,
			'section' 	=> 'title_tagline',
			'settings' 	=> 'clean_journal_theme_options[logo_alt_text]',
			'type'     	=> 'text',
		) );
	}

	$wp_customize->add_setting( 'clean_journal_theme_options[move_title_tagline]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['move_title_tagline'],
		'sanitize_callback' => 'clean_journal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'clean_journal_theme_options[move_title_tagline]', array(
		'label'    => __( 'Check to move Site Title and Tagline before logo', 'clean-journal-pro' ),
		'priority' => function_exists( 'has_custom_logo' ) ? 10 : 103,
		'section'  => 'title_tagline',
		'settings' => 'clean_journal_theme_options[move_title_tagline]',
		'type'     => 'checkbox',
	) );
	// Custom Logo End

	// Header Options (added to Header section in Theme Customizer)
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-header-options.php';


   	//Additional Menu Options
	$wp_customize->add_section( 'clean_journal_menu_options', array(
		'description'	=> __( 'Extra Menu Options specific to this theme', 'clean-journal-pro' ),
		'priority' 		=> 105,
		'title'    		=> __( 'Menu Options', 'clean-journal-pro' ),
	) );

	$wp_customize->add_setting( 'clean_journal_theme_options[primary_menu_disable]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['primary_menu_disable'],
		'sanitize_callback' => 'clean_journal_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'clean_journal_theme_options[primary_menu_disable]', array(
		'label'    => __( 'Check to disable Primary Menu', 'clean-journal-pro' ),
		'section'  => 'clean_journal_menu_options',
		'settings' => 'clean_journal_theme_options[primary_menu_disable]',
		'type'     => 'checkbox',
	) );

   	$wp_customize->add_setting( 'clean_journal_theme_options[primary_search_disable]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['primary_search_disable'],
		'sanitize_callback' => 'clean_journal_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'clean_journal_theme_options[primary_search_disable]', array(
		'label'    => __( 'Check to disable search box in Primary Menu', 'clean-journal-pro' ),
		'section'  => 'clean_journal_menu_options',
		'settings' => 'clean_journal_theme_options[primary_search_disable]',
		'type'     => 'checkbox',
	) );

	//Theme Options
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-theme-options.php';

	// Color Options
	// Moved from Default Color Control to Catbase Color Options
   	$wp_customize->get_control( 'background_color' )->section			= 'clean_journal_color_scheme';
	$wp_customize->get_control( 'header_textcolor' )->section			= 'clean_journal_header_color_options';

   	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-color-options.php';

	//Featured Content Setting
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-featured-content.php';

	//Featured Slider
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-featured-slider.php';

	//Social Links
	require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-social-icons.php';

	// Reset all settings to default
	$wp_customize->add_section( 'clean_journal_reset_all_settings', array(
		'description'	=> __( 'Caution: Reset all settings to default. Refresh the page after save to view full effects.', 'clean-journal-pro' ),
		'priority' 		=> 700,
		'title'    		=> __( 'Reset all settings', 'clean-journal-pro' ),
	) );

	$wp_customize->add_setting( 'clean_journal_theme_options[reset_all_settings]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['reset_all_settings'],
		'sanitize_callback' => 'clean_journal_sanitize_checkbox',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'clean_journal_theme_options[reset_all_settings]', array(
		'label'    => __( 'Check to reset all settings to default', 'clean-journal-pro' ),
		'section'  => 'clean_journal_reset_all_settings',
		'settings' => 'clean_journal_theme_options[reset_all_settings]',
		'type'     => 'checkbox',
	) );
	// Reset all settings to default end


	//Important Links
		$wp_customize->add_section( 'important_links', array(
			'priority' 		=> 999,
			'title'   	 	=> __( 'Important Links', 'clean-journal-pro' ),
		) );

		/**
		 * Has dummy Sanitizaition function as it contains no value to be sanitized
		 */
		$wp_customize->add_setting( 'important_links', array(
			'sanitize_callback'	=> 'clean_journal_sanitize_important_link',
		) );

		$wp_customize->add_control( new Clean_Journal_Important_Links( $wp_customize, 'important_links', array(
	        'label'   	=> __( 'Important Links', 'clean-journal-pro' ),
	         'section'  	=> 'important_links',
	        'settings' 	=> 'important_links',
	        'type'     	=> 'important_links',
	    ) ) );
	    //Important Links End
}
add_action( 'customize_register', 'clean_journal_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously for journal.
 * And flushes out all transient data on preview
 *
 * @since Clean Journal 1.0
 */
function clean_journal_customize_preview() {
	wp_enqueue_script( 'clean_journal_customizer', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'js/clean-journal-customizer.min.js', array( 'customize-preview' ), '20120827', true );

	//Flush transients
	clean_journal_flush_transients();
}
add_action( 'customize_preview_init', 'clean_journal_customize_preview' );


/**
 * Custom scripts and styles on customize.php for journal.
 *
 * @since Clean Journal Pro 1.0
 */
function clean_journal_customize_scripts() {
	wp_enqueue_script( 'clean_journal_customizer_custom', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'js/clean-journal-customizer-custom-scripts.min.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20150630', true );

	$clean_journal_data = array(
			'reset_message'        => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'clean-journal-pro' )
		);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'clean_journal_customizer_custom', 'clean_journal_data', $clean_journal_data );
}
add_action( 'customize_controls_enqueue_scripts', 'clean_journal_customize_scripts');


/**
 * Function to reset date with respect to condition
 */
function clean_journal_reset_data() {
	$options  = clean_journal_get_theme_options();
    if( $options['reset_all_settings'] ) {
    	remove_theme_mods();

        // Flush out all transients	on reset
        clean_journal_flush_transients();

        return;
    }

	$defaults = clean_journal_get_default_theme_options();
    if( $options['reset_footer_content'] ) {
    	//Reset Footer Editor Options
		$options['footer_content']     = $defaults[ 'footer_content' ];
		$options['reset_footer_content'] = 0;

		set_theme_mod( 'clean_journal_theme_options', $options );
    }

    if( $options['reset_typography'] ) {
    	$font_family_options = array(
			'title_font',
			'body_font',
			'tagline_font',
			'content_title_font',
			'content_font',
			'headings_font'
		);

		foreach ( $font_family_options as $font_family_option ) {
			$options[ $font_family_option ] = $defaults[ $font_family_option ];
		}

		$options['reset_typography'] = 0;

        set_theme_mod( 'clean_journal_theme_options', $options );
    }
}
add_action( 'customize_save_after', 'clean_journal_reset_data' );

//Active callbacks for customizer
require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-active-callbacks.php';


//Sanitize functions for customizer
require trailingslashit( get_template_directory() ) . 'inc/customizer-includes/clean-journal-customizer-sanitize-functions.php';
